# -*- coding:utf-8 -*-

"This is a test module"

__author__ = 'onlytiancai'
__author_email__ = 'onlytiancai@gmail.com'
__version__ = '1.0.1'

class Car(object):
    color = 'red'
    def run(self):
        '跑起来吧'
        print "I'm runing." 
